import * as ts from "typescript";
/**
 * Apply various updates to typescript files using AST
 */
export declare class TypeScriptFileUpdate {
    private targetPath;
    protected formatOptions: {
        spaces: boolean;
        indentSize: number;
        singleQuotes: boolean;
    };
    private fileSystem;
    private targetSource;
    private importsMeta;
    private requestedImports;
    private createdStringLiterals;
    /** Create updates for a file. Use `add<X>` methods to add transformations and `finalize` to apply and save them. */
    constructor(targetPath: string);
    /** Applies accumulated transforms, saves and formats the file */
    finalize(): void;
    addRoute(path: string, component: string, name: string, routerChildren: string, importAlias: string, routesVariable?: string): void;
    /** Initializes existing imports info, [re]sets import and `NgModule` edits */
    protected initState(): void;
    protected loadImportsMeta(): {
        lastIndex: number;
        modulePaths: any[];
    };
    protected addRouteModuleEntry(path: string, component: string, name: string, routerChildren: string, importAlias: string, routesVariable?: string): void;
    protected requestImport(modulePath: string, routerAlias: string): void;
    /** Add `import` statements not previously found in the file  */
    protected addNewFileImports(): void;
    protected createIdentifierImport(importPath: string, as: string): ts.ImportDeclaration;
    /** Transformation to apply edits to existing named import declarations */
    protected importsTransformer: ts.TransformerFactory<ts.Node>;
    /** Format a TS source file, very TBD */
    protected formatFile(filePath: string): void;
    /**  Try and parse formatting from project `.editorconfig` / `tslint.json` */
    protected readFormatConfigs(): void;
    /**
     * Apply formatting changes (position based) in reverse
     * from https://github.com/Microsoft/TypeScript/issues/1651#issuecomment-69877863
     */
    private applyChanges;
    /** Return source file formatting options */
    private getFormattingOptions;
    /** Get language service host, sloppily */
    private getLanguageHost;
    /** Convert a string or string array union to array. Splits strings as comma delimited */
    private asArray;
    private createVisitor;
    private createRouteEntry;
}
